diff --git a/chainlink.py b/chainlink.py
index 64edcc3..6157fd1 100755
--- a/chainlink.py
+++ b/chainlink.py
@@ -42,7 +42,7 @@ def root():
html |
Hit the IPFS hash via cloudflare-ipfs.com |
redir |
@@ -74,7 +74,7 @@ def redirectDomain(domain, action=None):
else:
ipfshash = ipfs_hash
response.set_header('Location',
- f"https://cloudflare-ipfs.com/{ipfshash}")
+ f"https://gateway.ipfs.io/{ipfshash}")
elif action == 'redir':
try:
if not redirect_url.startswith('http'):
@@ -42,7 +42,7 @@ def root():
html |
- Hit the IPFS hash via cloudflare-ipfs.com |
+ Hit the IPFS hash via gateway.ipfs.io |
redir |